@@ -107,13 +107,13 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 	QObject::connect(aboutButton, SIGNAL(clicked()), this, SLOT(about()));
 	dlgBtnBox->addButton(aboutButton, QDialogButtonBox::ActionRole);
 
-	QPushButton * deleteButton = new QPushButton(QIcon(":/resources/delete.png"), "Delete DB", this);
-	deleteButton->setFixedHeight(70);
-	deleteButton->setContextMenuPolicy(Qt::NoContextMenu);
-	deleteButton->setFocusPolicy(Qt::NoFocus);
-	deleteButton->setIconSize(QSize(48, 48));
-	QObject::connect(deleteButton, SIGNAL(clicked()), this->parent, SLOT(deleteDB()));
-	dlgBtnBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
+//	QPushButton * deleteButton = new QPushButton(QIcon(":/resources/delete.png"), "Delete DB", this);
+//	deleteButton->setFixedHeight(70);
+//	deleteButton->setContextMenuPolicy(Qt::NoContextMenu);
+//	deleteButton->setFocusPolicy(Qt::NoFocus);
+//	deleteButton->setIconSize(QSize(48, 48));
+//	QObject::connect(deleteButton, SIGNAL(clicked()), this->parent, SLOT(deleteDB()));
+//	dlgBtnBox->addButton(deleteButton, QDialogButtonBox::ActionRole);
 
 	QPushButton * exitButton = new QPushButton(QIcon(":/resources/exit.png"), "Exit", this);
 	exitButton->setFixedHeight(70);
@@ -155,11 +155,13 @@ void LoginDialog::about()
 }
 void LoginDialog::clearS()
 {
-	label->setText ("");
-	current = "";
+	label->selectAll();
+	label->del();
 }
 
 void LoginDialog::acceptS() {
+	QString current = label->text();
+
 	if (current.length() == 0) {
 		if (messageBox.isNull()) {
 			messageBox = new QMessageBox(this);
@@ -212,13 +214,13 @@ void LoginDialog::acceptS() {
 }
 
 void LoginDialog::select(const QString& a) {
-	if (current.size() < KEY_SIZE) {
-		current += a;
+	if (label->text().size() < KEY_SIZE) {
+		QString current = label->text() + a;
 		label->setText (current); //QString ("************************").right(current.size()));
 	}
 }
 
-//void LoginDialog::keyPressEvent(QKeyEvent* event) {
+void LoginDialog::keyPressEvent(QKeyEvent* event) {
 //	//qDebug()<<"key pressed " << event->key();
 //
 //	if (event->key() >= Qt::Key_0 && event->key() <= Qt::Key_9) {
@@ -237,17 +239,19 @@ void LoginDialog::select(const QString& a) {
 //			event->accept();
 //		}
 //		else {
-//			if (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) {
-//				event->accept();
-//				acceptS();
-//			}
-//			else {
-//				event->accept();//QWidget::keyPressEvent(event);
+	if (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) {
+				event->accept();
+				acceptS();
+			}
+			else {
+				QCoreApplication::sendEvent (label, event);
+			}
+	//				event->accept();//QWidget::keyPressEvent(event);
 //QLineEdit::keyPressEvent(event);
 //			}
 //		}
 //	}
-//}
+}
 
 void LoginDialog::resetF () {
 	isFirstTime = true;
