@@ -59,53 +59,57 @@ eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 }
 
 void eWallet::showList () {
+	isAskPassword = false;
+
 	setProperty("FingerScrollable", false);
 	//setContextMenuPolicy(Qt::NoContextMenu);
 	//                         // Central widget and Layout
-	centralWidget = new QWidget(this);
+	if (!centralWidget) {
+		centralWidget = new QWidget(this);
 
-//	setContextMenuPolicy(Qt::DefaultContextMenu);
-//	centralWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
+		setContextMenuPolicy(Qt::DefaultContextMenu);
+	//	centralWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
 
-	vboxlayout = new QVBoxLayout;
-	vboxlayout->setSpacing(0);
-	vboxlayout->setMargin(0);
-	// Custom list box
+		vboxlayout = new QVBoxLayout;
+		vboxlayout->setSpacing(0);
+		vboxlayout->setMargin(0);
+		// Custom list box
 
-	fnListWidget = new QListWidget(this);
-	vboxlayout->addWidget(fnListWidget);
+		fnListWidget = new QListWidget(this);
+		vboxlayout->addWidget(fnListWidget);
 
-	QObject::connect(fnListWidget, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(selectItem(QListWidgetItem *)));
-	QObject::connect(fnListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(selectDItem(QListWidgetItem *)));
+		QObject::connect(fnListWidget, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(selectItem(QListWidgetItem *)));
+		QObject::connect(fnListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(selectDItem(QListWidgetItem *)));
 
-	inputWidget = new QHBoxLayout;
-	inputWidget->setContentsMargins(2, 2, 2, 0);
-	vboxlayout->addLayout(inputWidget);
+		inputWidget = new QHBoxLayout;
+		inputWidget->setContentsMargins(2, 2, 2, 0);
+		vboxlayout->addLayout(inputWidget);
 
-	cancelSearch = new QPushButton(QIcon(":/resources/icon_clear.png"), "", this);
-	searchField = new QLineEdit ();
-	hideSearch = new QPushButton(QIcon(":/resources/icon_hide.png"), "", this);
+		cancelSearch = new QPushButton(QIcon(":/resources/icon_clear.png"), "", this);
+		searchField = new QLineEdit ();
+		hideSearch = new QPushButton(QIcon(":/resources/icon_hide.png"), "", this);
 
-	inputWidget->addWidget(cancelSearch);
-	inputWidget->addWidget(searchField);
-	inputWidget->addWidget(hideSearch);
+		inputWidget->addWidget(cancelSearch);
+		inputWidget->addWidget(searchField);
+		inputWidget->addWidget(hideSearch);
 
-	QObject::connect(cancelSearch, SIGNAL(clicked()), this, SLOT(_cancelSearch()));
-	QObject::connect(hideSearch, SIGNAL(clicked()), this, SLOT(_hideSearch()));
-	QObject::connect(searchField, SIGNAL(textChanged(const QString &)), this, SLOT(textChanged(const QString &)));
+		QObject::connect(cancelSearch, SIGNAL(clicked()), this, SLOT(_cancelSearch()));
+		QObject::connect(hideSearch, SIGNAL(clicked()), this, SLOT(_hideSearch()));
+		QObject::connect(searchField, SIGNAL(textChanged(const QString &)), this, SLOT(textChanged(const QString &)));
 
-	cancelSearch->hide ();
-	searchField->hide ();
-	hideSearch->hide ();
+		cancelSearch->hide ();
+		searchField->hide ();
+		hideSearch->hide ();
+
+		centralWidget->setLayout(vboxlayout);
+		setCentralWidget(centralWidget);
+
+		createMenu ();
+
+		centralWidget->setFocus ();
+	}
 
 	showTargets (true);
-
-	centralWidget->setLayout(vboxlayout);
-	setCentralWidget(centralWidget);
-
-	createMenu ();
-
-	centralWidget->setFocus ();
 }
 
 void eWallet::selectItem(QListWidgetItem * item) {
@@ -329,18 +333,20 @@ void eWallet::loadTypesAndFields () {
 void eWallet::keyPressEvent(QKeyEvent* event) {
 	//qDebug()<<"key pressed " << event->key();
 	
-	if (searchField != NULL && searchField->isHidden()) {
-		cancelSearch->show ();
-		searchField->show ();
-		hideSearch->show ();
-		searchField->setFocus();
+	if (!isAskPassword) {
+		if (searchField->isHidden()) {
+			cancelSearch->show ();
+			searchField->show ();
+			hideSearch->show ();
+			searchField->setFocus();
 
-		QCoreApplication::sendEvent (searchField, event);
+			QCoreApplication::sendEvent (searchField, event);
 
-		event->accept();
+			event->accept();
+		}
 	}
 	else {
-		event->accept();
+		QWidget::keyPressEvent(event);//event->accept();
 	}
 	//timer->stop();
 	//timer->start(5000);
@@ -418,14 +424,24 @@ void eWallet::showTargets(bool reset)
 
 void eWallet::createMenu()
 {
-	menuBar()->addAction("New", this, SLOT(newTarget()));
-	menuBar()->addAction("Edit", this, SLOT(_editcTarget()));
-	menuBar()->addAction("Invert Sort", this, SLOT(sort()));
-	menuBar()->addAction("Import", this, SLOT(import()));
-	menuBar()->addAction("Export", this, SLOT(exportData()));
-	menuBar()->addAction("About", this, SLOT(about()));
-	menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
+	if (isAskPassword) {
+		menuBar()->clear();
 
+		menuBar()->addAction("About", this, SLOT(about()));
+		menuBar()->addAction("Delete DB", this, SLOT(deleteDB()));
+		menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
+	}
+	else {
+		menuBar()->clear();
+
+		menuBar()->addAction("New", this, SLOT(newTarget()));
+		menuBar()->addAction("Edit", this, SLOT(_editcTarget()));
+		menuBar()->addAction("Invert Sort", this, SLOT(sort()));
+		menuBar()->addAction("Import", this, SLOT(import()));
+		menuBar()->addAction("Export", this, SLOT(exportData()));
+		menuBar()->addAction("About", this, SLOT(about()));
+		menuBar()->addAction("Exit", QApplication::instance(), SLOT(quit()));
+	}
 }
 
 void eWallet::sort()
@@ -729,13 +745,13 @@ void eWallet::newTarget() {
 		//detailWindow->exec();
 	}
 }
-/*
+
 void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 	//qDebug () << "Should be show " << this->childAt(event->globalPos());
 
-	row = this->fnListWidget->findOn (event->globalPos());
+	if (fnListWidget->currentRow() >= 0) {
+	Target * target = list.at(fnListWidget->currentRow());
 
-	if (row >= 0) {
 		QMenu menu(this);
 		menu.addAction("View", this, SLOT(_viewcTarget()));
 		menu.addAction("Edit", this, SLOT(_editcTarget()));
@@ -743,7 +759,6 @@ void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 		menu.exec(event->globalPos());
 	}
 }
-*/
 
 void eWallet::exportData() {
 	QString path(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
@@ -792,6 +807,10 @@ void eWallet::_editcTarget() {
 	//editTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 void eWallet::_deletecTarget() {
+	if (fnListWidget->currentRow() >= 0) {
+		Target * target = list.at(fnListWidget->currentRow());
+		deleteTarget(target);
+	}
 	//deleteTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 void eWallet::_viewcTarget() {
@@ -812,7 +831,8 @@ void eWallet::closeEvent(QCloseEvent *event){
 void eWallet::askPassword () {
 	times = 0;
 	
-	menuBar()->clear();
+	isAskPassword = true;
+	createMenu();
 
 	if (loginDialogDlg.isNull()) {
 		loginDialogDlg = new LoginDialog(!::dbManager->hasPassword (), this);
@@ -821,13 +841,13 @@ void eWallet::askPassword () {
 		setCentralWidget(loginDialogDlg);
 		loginDialogDlg->setFocus ();
 
-		centralWidget = NULL;
-		vboxlayout = NULL;
-		fnListWidget = NULL;
-		inputWidget = NULL;
-		cancelSearch = NULL;
-		searchField = NULL;
-		hideSearch = NULL;
+//		centralWidget = NULL;
+//		vboxlayout = NULL;
+//		fnListWidget = NULL;
+//		inputWidget = NULL;
+//		cancelSearch = NULL;
+//		searchField = NULL;
+//		hideSearch = NULL;
 	}
 }
 
